import json
import requests

class Chapter:
    """chapters list/info"""

    def __init__(self):
        """Initialize"""
        self.api = 'https://api.quran.com/api/v4/chapters' 

    def chapters_list(self, lang='en'):
        """Get list of chapters"""

        response = requests.get(f"{self.api}?language={lang}")
        return json.loads(response.text)

    def get_ichapter(self, chapter_id, lang='en'):
        """Get details of a single chapter."""

        response = requests.get(f"{self.api}/{chapter_id}?language={lang}")
        return json.loads(response.text)

    def chapter_info(self, chapter_id, lang='en'):
        """Get Chapter Info in specific language. Default to English."""

        response = requests.get(f"{self.api}/{chapter_id}/info?language={lang}")
        return json.loads(response.text)        




import json
import requests


class Verses:
    """ Class designed to fetch one complete translation, tafsir, recitation or ayah text of whole Quran. """

    def __init__(self):
        """Initialize"""

        self.api = 'https://api.quran.com/api/v4/quran' 
    
    def get_chapter(self, chapter_number, script=1):
        """Get script of a specific surah."""
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"

        response = requests.get(f"{self.api}/verses/{script}?chapter_number={chapter_number}")
        return json.loads(response.text)

    def get_juz(self, juz_number, script=1):
        """Get script of a specific juz."""
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"        

        response = requests.get(f"{self.api}/verses/{script}?juz_number={juz_number}")
        return json.loads(response.text)

    def get_page(self, page_number, script=1):
        """Get script of a specific page."""
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"

        response = requests.get(f"{self.api}/verses/{script}?page_number={page_number}")
        return json.loads(response.text)

    def get_hizb(self, hizb_number, script=1):
        """Get script of a specific hizab."""
        
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"

        response = requests.get(f"{self.api}/verses/{script}?hizb_number={hizb_number}")
        return json.loads(response.text)    

    def get_rub(self, rub_number, script=1):
        """Get script of a specific rub."""
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"

        response = requests.get(f"{self.api}/verses/{script}?rub_number={rub_number}")
        return json.loads(response.text)  

    def get_verse(self, verse_key, script=1):
        """Get script of a specific verse."""
        if script == 1:
            script = "imlaei"
        elif script == 2:
            script = "imlaei_simple"
        elif script == 3:
            script = "indopak"
        elif script == 4:
            script = "uthmani"
        elif script == 5:
            script = "uthmani_simple"
        elif script == 6:
            script = "uthmani_tajweed"

        response = requests.get(f"{self.api}/verses/{script}?verse_key={verse_key}")
        return json.loads(response.text)   


import json
import requests

class Ajza:
    """Ajza/juzs list"""

    def __init__(self):
        """Initialize"""
        
        self.api = 'https://api.quran.com/api/v4/juzs' 

    def juzs_list(self, lang='en'):
        """Get list of all ajza/juzs"""

        response = requests.get(f"{self.api}?language={lang}")
        return json.loads(response.text)

    def get_ijuz(self, juz_id, lang='en'):
        """Get details of a single juz."""

        response = requests.get(f"{self.api}/{juz_id}?language={lang}")
        return json.loads(response.text)


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="quran.py",
    version="0.1",
    author="Jadtz",
    author_email="amjid482@gmail.com",
    description="An API wrapper for Quran.com written in Python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Jadtz/quran.py",
    project_urls={
        "Bug Tracker": "https://github.com/Jadtz/quran.py/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.8",
    install_requires=[
    'certifi==2020.12.5',
    'chardet==4.0.0',
    'idna==2.10',
    'requests==2.25.1',
    'urllib3==1.26.4'
    ]
)


import json
import requests


class Translation:
    """ Get a single a single chapter or ayah. """

    def __init__(self):
        """Initialize"""
        self.api_1 = 'https://api.quran.com/api/v4/resources/translations'
        self.api_2 = 'https://api.quran.com/api/v4/quran/translations'

    def list_translations(self, lang="en"):
        """Get list of available translations.""" 

        response = requests.get(f"{self.api_1}?language={lang}")
        return json.loads(response.text)

    def get_tchapter(self, chapter_number, translation_id=20):
        """Get information of a specific translation.""" 

        response = requests.get(f"{self.api_2}/{translation_id}?chapter_number={chapter_number}")
        return json.loads(response.text)
    
    def get_tverse(self, verse_key, translation_id=20):
        """Get translation of a specific ayah."""

        response = requests.get(f"{self.api_2}/{translation_id}?verse_key={verse_key}")
        return json.loads(response.text)